#
# spec file for package abcm2ps
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2007 by Edgar Aichinger
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           abcm2ps
Version:        8.14.14
Release:        1.4
Summary:        A program to typeset abc tunes into Postscript
License:        LGPL-3.0-or-later
Group:          Productivity/Publishing/Other
Summary(de):    Ein Werkzeug um ABC-Notationen in Postscript zu drucken
URL:            https://github.com/leesavide/abcm2ps/
Source0:        https://github.com/leesavide/abcm2ps/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        italian.fmt
Source2:        deco-guitar.fmt
Source3:        deco-marks.fmt
Source4:        renaissance.fmt
Source5:        thinlines.fmt
# PATCH-FIX-OPENSUSE compiler_flags.patch -- aloisio@gmx.com
Patch0:         compiler_flags.patch
BuildRequires:  pkgconfig
# for rst2man
BuildRequires:  python3-docutils
# for rendering non-latin characters in Postscript output
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(pangocairo)

%description
abcm2ps is a package which converts music tunes from ABC format to
PostScript. Based on abc2ps version 1.2.5, it was developed mainly to print
barock organ scores which have independent voices played on one or many
keyboards and a pedal board. abcm2ps introduces many extensions to the ABC
language that make it suitable for classical music.

%prep
%setup -q
%patch0 -p1
mv config.h.in config.h.sed
sed "s/\/\/#define A4_FORMAT/#define A4_FORMAT/" config.h.sed > config.h.in

%build
%configure
make %{?_smp_mflags}

%install
%make_install
# remove documentation and examples from wrong install path
rm -rf %{buildroot}/%{_datadir}/doc

%files
%license COPYING
%doc README.md *.abc sample3.eps
%{_bindir}/*
%{_datadir}/%{name}
%{_mandir}/man1/%{name}*

%changelog
* Mon Dec 19 2022 Michael Vetter <mvetter@suse.com>
- Update to 8.14.14:
  * move the single bars 1 point to the left (#109)
  * fix: lack of error when decoration type 2, 5, 6 or 7 on a note head
  * fix: remove lines starting with one '%%' instead of removing the
    character
  * fix: loss of !tremn! in grace notes since some version 8.xx.xx
  * fix: remove warnings dealing with accesses to dynamically allocated
    arrays (#110)
  * fix: lack of color on multi-rests
  * fix: %%%%repeat not working
  * add %%%%header2 and %%%%footer2 for even pages
* Tue Feb  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 8.14.13:
  * fix: don't start/stop slurs above/below decorations
  * fix: crash when too many notes in a grace note sequence (#102)
  * fix: crash when too big value in M: (#103)
  * fix: loop or crash when too big width of y (space) (#104)
  * fix: bad font definition with SVG output when spaces in font name
  * fix: bad check of note length again (#106)
  * fix: handle %%%%staffscale at the global level (#108)
  * fix: bad vertical offset of lyrics when mysic line starts with
    empty staves
* Thu Jul 15 2021 Michael Vetter <mvetter@suse.com>
- Update to 8.14.12:
  Fixes:
  * crash when "%%%%break 1" and no measure bar in the tune
  * crash when duplicated voice ending on %%%%staves with repeat variant
  * crash when voice duplication with symbols without width
  * crash or bad output when null value in %%%%scale
  * problem when only bars in 2 voices followed %%%%staves of the second voice only
  * crash when tuplet error in grace note sequence
  * crash when grace note with empty tuplet
  * crash when many broken rhythms after a single grace note
  * access outside the deco array when error in U:
  * crash when !xstem! with no note in the previous voice
  * crash on tuplet without any note/rest
  * crash when grace notes at end of line and voice overlay
  * crash when !trem2! at start of a grace note sequence
  * crash when wrong duration in 2 voice overlays and bad ties
  * crash when accidental without a note at start of line after K: (CVE-2021-32435)
  * array overflow when wrong duration in voice overlay (CVE-2021-32434, CVE-2021-32436)
  * loss of left margin after first page since previous commit
  * no respect of %%%%leftmargin with -E or -g
  * bad placement of chord symbols when in a music line with only invisible rests
  Syntax:
  * Accept and remove one or two '%%'s at start of all %%%%beginxxx lines
  Generation:
  * Move the CSS from XHTML to SVG
  Build:
  * configure: respect environment variable
- Refresh compiler_flags.patch
* Mon Dec  7 2020 Michael Vetter <mvetter@suse.com>
- Update to 8.14.11:
  * fix: error "'staffwidth' too small" when generating sample3.abc
* Mon Nov 23 2020 Michael Vetter <mvetter@suse.com>
- Update to 8.14.10:
  * fix: bad glyph when defined by SVG containing 'v' in
  * fix: bad check of note length since commit 191fa55
  * fix: memory corruption when error in %%%%staves/%%%%score
  * fix: crash when too big note duration
  * fix: crash when staff width too small
* Mon Jun 22 2020 Michael Vetter <mvetter@suse.com>
- Update to 8.14.9:
  * fix: bad natural accidental when %%%%MIDI temperamentequal
* Mon Jun 22 2020 Michael Vetter <mvetter@suse.com>
- Update to 8.14.8:
  * fix: no respect the width in %%%%staffbreak
  * fix: don't draw a staff when only %%%%staffbreak inside
  * fix: bad repeat bracket when continued on next line, line starting by a bar
  * fix: bad tuplet bracket again when at end of a voice overlay sequence
  * fix: bad tuplet bracket when at end of a voice overlay sequence
  * handle '%%%%MIDI temperamentequal '
  * accept '^1' and '_1' as microtone accidentals
* Wed Feb 19 2020 Michael Vetter <mvetter@suse.com>
- Update to 8.14.7:
  * crash when %%%%score with no common voices and next notes with beams
  * crash when new staff system with only new voices
  * crash when slash found before a bar and not a (deprecated) measure repeat
  * crash when %%%%staves at end of tune and lack of music in the last voice
  * bad parsing of the note durations
  * clash of some ties with dots
  * bad check of the number of measures in Z (multi-rest)
  * new improved coda sign
  * Make pkg-config substitutable for cross-compilations
  * add option tieheight factor to tie height like in slurheight
  * add some decorations from v2.2 standard
* Fri Nov  8 2019 Michael Vetter <mvetter@suse.com>
- Update compiler_flags.patch
* Fri Nov  8 2019 Michael Vetter <mvetter@suse.com>
- Update to 8.14.6:
  * bad voice combine '3' when 3 voices and unison
  * don't separate the accents from the notes by tuplets
  * clash of tuplet numbers with accents
  * bad time signature when C or C| and more value(s)
  * warnings from clang static analysis
  * bad music font selection when not defined by 'url(..)'
  * bad vertical offset of "%%%%multicol new" when W: and %%%%begintext
  * bad handling of fonts
  * Add option flatbeamgracing that applies flat beams to grace notes only
  * put the upper tuplets a bit closer to the notes
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Thu Jul 18 2019 mvetter@suse.com
- Update to 8.14.5:
  * staves not joined by bars when intermediate staff not displayed
  * 'sample8.html' was not installed
  * license moved to LGPL >= 3
  * don't limit the volta brackets to the length of the first ending
* Sat May 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Added compiler_flags.patch to fix Factory build
- Renamed source tarball to follow the name-version custom
* Mon Mar 18 2019 mvetter@suse.com
- Update to 8.14.4:
  * program loop when P: on beamed note at end of line and %%%%breakoneoln 0
  * crash/loop when slur between note and grace note and other slurs later
* Mon Mar 11 2019 mvetter@suse.com
- Update to 8.14.3:
  * erroneous double '8va's on a same staff when set on combined notes/rests
  * don't put two '8va's on the same staff
  * loss of %%%%sep since previous version
* Sat Dec 22 2018 Michael Vetter <mvetter@suse.com>
- Update to 8.14.2:
  * !8va! must be above the staff
  * crash when SVG output and call to an unknown symbol in PS sequence
  * crash when no note in voice overlay
  * crash when SVG output and 'F' is not a font name in a PS sequence
  * crash when only one bar in a voice and no symbol in a second voice
  * possible crashes when bad definition of special decorations
  * crash on decoration type 7 without start/stop
  * crash on decoration type 5 without start/stop
  * crash when unterminated decoration in U:
  * crash when random character greater than 128 in a s: line
  * bad test of font encoding
  * read access outside of array when exact memory allocation of w:
  * read access outside of array on small line starting with %%%%
  * fixes from Debian (Makefile/configure/INSTALL)
* Mon Nov 19 2018 mvetter@suse.com
- Update to 8.14.1:
  * bad definition of the music font (@font-face[1])
  * bad error when --pango 2 in command line and SVG output
  * bad beams when notes on 2 staves and %%%%flatbeams
  * error in SVG output when color setting since version v8.14.0
  * code revert: use pango only when needed
  * crash in 'make install' when no 'rst2man' in the shell PATH
* Mon Sep 24 2018 Jan Engelhardt <jengelh@inai.de>
- Fix some grammar issues in descriptions.
- Use %%configure macro.
* Fri Sep 21 2018 Edgar Aichinger <edogawa@aon.at>
- more work on spec to enable A4 paper format and use pango for non-latin characters in PS output
- use make install target instead of custom commands in specfile
* Thu Sep 13 2018 Edgar Aichinger <edogawa@aon.at>
- some minor specfile tweaks to reduce rpmlint warnings
* Wed Sep 12 2018 mvetter@suse.com
- Update to 8.14.0:
  * better handling of fonts when pango
  * bad transposition when chord symbols separated by ';'
  * always use pango when available
  * Use CSS shorthand file description for SVG output
  build:
  * Split clean targets according to the GNU guidelines
  * Install documentation into prefix/share/doc instead of prefix/doc
  * Install the examples in a separate documentation directory
  documentation:
  * add man page
- Use github URL in source field
- Clean up spec file with spec-cleaner
- Clean up spec file according to rpmlint warnings
- Use %%license tag for COPYING file
- Dont install INSTALL file
* Fri Jan 12 2018 edogawa@aon.at
- updated to version 8.13.18
- sources are on github now, changed specfile accordingly
* Tue May 21 2013 edogawa@aon.at
- updated to version 6.6.22
* Thu Aug  5 2010 edogawa@aon.at
- updated to version 5.9.15
- updated/added format files from abcplus page
* Fri Dec 11 2009 edogawa@aon.at
- updated to version 5.9.7
* Tue Oct 20 2009 edogawa@aon.at
- updated to version 5.9.6
* Wed Aug 12 2009 edogawa@aon.at
- updated to version 5.9.5
* Fri Apr 24 2009 edogawa@aon.at
- updated to version 5.9.4
* Sun Jul  8 2007 edogawa@aon.at
- updated to version 4.12.30
* Thu Jan  4 2007 christian@links2linux.de
- added 3 .fmt extensions
* Wed Jan  3 2007 christian@links2linux.de
- taken from "original" src.rpm from the project homepage
  rewritten for packman
- initial version 4.12.27
